Rename library and update build system

Change-Id: I78c6a412c5e2181e58649c0e0aa2aa2f97da16a1
diff --git a/src/interval.cpp b/src/interval.cpp
index 8d96f77..1402baf 100644
--- a/src/interval.cpp
+++ b/src/interval.cpp
@@ -2,19 +2,19 @@
 /**
  * Copyright (c) 2014-2018, Regents of the University of California
  *
  * This file is part of ndn-group-encrypt (Group-based Encryption Protocol for NDN).
  * See AUTHORS.md for complete list of ndn-group-encrypt authors and contributors.
  *
  * ndn-group-encrypt is free software: you can redistribute it and/or modify it under the terms
  * of the GNU General Public License as published by the Free Software Foundation,
  * either version 3 of the License, or (at your option) any later version.
  *
- * ndn-group-encrypt is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+ * NAC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  * PURPOSE.  See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * ndn-group-encrypt, e.g., in COPYING.md file.  If not, see <http://www.gnu.org/licenses/>.
+ * NAC, e.g., in COPYING.md file.  If not, see <http://www.gnu.org/licenses/>.
  *
  * @author Zhiyi Zhang <zhiyi@cs.ucla.edu>
  */
@@ -22,7 +22,7 @@
 #include "interval.hpp"
 
 namespace ndn {
-namespace gep {
+namespace nac {
 
 static const TimeStamp DEFAULT_TIME = boost::posix_time::from_iso_string("14000101T000000");
 
@@ -109,5 +109,5 @@
   return *this;
 }
 
-} // namespace gep
+} // namespace nac
 } // namespace ndn
@@ -2,19 +2,19 @@
  * Copyright (c) 2014-2018, Regents of the University of California
  *
- * This file is part of ndn-group-encrypt (Group-based Encryption Protocol for NDN).
- * See AUTHORS.md for complete list of ndn-group-encrypt authors and contributors.
+ * This file is part of NAC (Name-Based Access Control for NDN).
+ * See AUTHORS.md for complete list of NAC authors and contributors.
  *
@@ -2,19 +2,19 @@
  *
- * ndn-group-encrypt is free software: you can redistribute it and/or modify it under the terms
+ * NAC is free software: you can redistribute it and/or modify it under the terms
  * of the GNU General Public License as published by the Free Software Foundation,
  * either version 3 of the License, or (at your option) any later version.